// The module 'vscode' contains the VS Code extensibility API
// Import the module and reference it with the alias vscode in your code below
import * as vscode from 'vscode';

// this method is called when your extension is activated
// your extension is activated the very first time the command is executed
export function activate(context: vscode.ExtensionContext) {

	// Use the console to output diagnostic information (console.log) and errors (console.error)
	// This line of code will only be executed once when your extension is activated
	console.log('Congratulations, your extension "demo-environmentvariablecollection" is now active!');

	// The command has been defined in the package.json file
	// Now provide the implementation of the command with registerCommand
	// The commandId parameter must match the command field in package.json
	let disposable = vscode.commands.registerCommand('demo-environmentvariablecollection.environmentVariableCollectionDemo', async () => {
		const action = await vscode.window.showQuickPick([
			'Prepend to terminal environment variable',
			'Append to terminal environment variable',
			'Replace terminal environment variable',
			'Show terminal environment variables',
		])
		if (action == 'Show terminal environment variables'){
			context.environmentVariableCollection.forEach(
				(v, _mut, col) => {
					console.log(v, "=>", col.get(v));
				}
			);
			return;
		}
		const environmentVariable = await vscode.window.showInputBox(
			{
				prompt: "Environment variable (eg: PATH, HOME, etc)"
			}
		)
		if (environmentVariable === undefined) {
			return;
		}
		const input = await vscode.window.showInputBox(
			{
				prompt: "Value to append/prepend/replace"
			}
		)
		if (input === undefined) {
			return;
		}
		
		if (action === 'Prepend to terminal environment variable'){
			context.environmentVariableCollection.prepend(environmentVariable, input);
			console.log(`prepend ${input} to ${environmentVariable}`)
		}
		if (action === 'Append to terminal environment variable'){
			context.environmentVariableCollection.append(environmentVariable, input);
			console.log(`append ${input} to ${environmentVariable}`)
		}
		if (action === 'Replace terminal environment variable'){
			context.environmentVariableCollection.replace(environmentVariable, input);
			console.log(`replace ${input} to ${environmentVariable}`)
		}
		console.log(`Environment updated (${action} / ${input})`);
	});
	context.subscriptions.push(disposable);
}

// this method is called when your extension is deactivated
export function deactivate() {}
